<?php
/**
 * NOTICE OF LICENSE
 *
 * @author    Connectpay  <https://connectpay.com/
 * @copyright Copyright (c) permanent, ConnectPay Inc.
 * @license   Apache License
 *
 * @see       /LICENSE
 *
 *  International Registered Trademark & Property of ConnectPay Inc.
 */

declare(strict_types=1);

use Invertus\ConnectPay\Adapter\Configuration;
use Invertus\ConnectPay\Adapter\Tools;
use Invertus\ConnectPay\Config\ConnectPayConfig;

if ( ! defined('_PS_VERSION_')) {
    exit;
}

/**
 * Class AdminConnectPayStatesController - used for orders states mapping.
 */
class AdminConnectPayStatesController extends ModuleAdminController
{

    /** @var ConnectPay */
    public $module;

    public function __construct()
    {
        $this->bootstrap = true;
        parent::__construct();
    }

    public function init(): void
    {
        parent::init();

        $this->initConnectFieldForm();
    }

    public function postProcess(): void
    {
        parent::postProcess();

        /** @var Tools $tools */
        $tools = $this->module->getService(Tools::class);
        /** @var Configuration $configuration */
        $configuration = $this->module->getService(Configuration::class);

        $shopId = $this->context->shop->id;

        if ($tools->isSubmit('submitOptionsconfiguration')) {
            foreach (ConnectPayConfig::CONNECTPAY_ORDER_STATES_WITH_NAMES as $state) {
                $configuration->set($state, $tools->getValue($state), $shopId);
            }
        }
    }

    private function initConnectFieldForm(): void
    {
        $this->fields_options = [
            'states_mapping' => [
                'title'                   => $this->l('Map ConnectPay states and your order states'),
                'icon'                    => 'icon-settings',
                'hide_multishop_checkbox' => true,
                'buttons'                 => [
                    'save' => [
                        'title' => $this->l('Save'),
                        'icon'  => 'process-icon-save',
                        'class' => 'btn btn-default',
                        'type'  => 'submit',
                    ],
                ],
            ],
        ];

        $orderStatesList = $this->getOrderStates();

        foreach (ConnectPayConfig::CONNECTPAY_ORDER_STATES_WITH_NAMES as $key => $stateName) {
            $this->fields_options['states_mapping']['fields'][$stateName] = [
                'form_group_class' => 'login-inputs',
                'title'            => $key,
                'type'             => 'select',
                'list'             => $orderStatesList,
                'identifier'       => 'id_order_state',
                'required'         => false,
            ];
        }
    }

    private function getOrderStates(): ?array
    {
        return OrderState::getOrderStates((int)$this->context->language->id);
    }

}