<?php
/**
 * NOTICE OF LICENSE
 *
 * @author    Connectpay  <https://connectpay.com/
 * @copyright Copyright (c) permanent, ConnectPay Inc.
 * @license   Apache License
 *
 * @see       /LICENSE
 *
 *  International Registered Trademark & Property of ConnectPay Inc.
 */

declare(strict_types=1);

namespace Invertus\ConnectPay\Infrastructure\Adapter;

use Context;
use Invertus\ConnectPay\Infrastructure\Utility\VersionUtility;

class PrestaContextAdapter implements PrestaContextAdapterInterface
{
    public function getShopId(): int
    {
        return (int) Context::getContext()->shop->id;
    }

    public function getLanguageId(): int
    {
        return (int) Context::getContext()->language->id;
    }

    public function getCurrencyIso(): string
    {
        if (!Context::getContext()->currency) {
            return '';
        }

        return (string) Context::getContext()->currency->iso_code;
    }

    public function getCustomerId(): int
    {
        if (!Context::getContext()->customer) {
            return 0;
        }

        return (int) Context::getContext()->customer->id;
    }

    public function getShopDomain(): string
    {
        return (string) Context::getContext()->shop->domain;
    }

    public function getShopName(): string
    {
        return (string) Context::getContext()->shop->name;
    }

    public function getAdminLink(string $controllerName, array $params = []): string
    {
        if (VersionUtility::isPsVersionLowerThan1700()) {
            $query = http_build_query($params);
            $link = Context::getContext()->link->getAdminLink($controllerName, true);

            return "{$link}&{$query}";
        }

        /* @noinspection PhpMethodParametersCountMismatchInspection - its valid for PS1.7 */
        return (string) Context::getContext()->link->getAdminLink($controllerName, true, [], $params);
    }

    public function getModuleLink(
        string $module,
        $controller = 'default',
        array $params = [],
        $ssl = null,
        $idLang = null,
        $idShop = null,
        $relativeProtocol = false
    ): string {
        return (string) Context::getContext()->link->getModuleLink(
            $module,
            $controller,
            $params,
            $ssl,
            $idLang,
            $idShop,
            $relativeProtocol
        );
    }

    public function getSmarty(): \Smarty
    {
        return Context::getContext()->smarty;
    }
}
