<?php
/**
 * NOTICE OF LICENSE
 *
 * @author    Connectpay  <https://connectpay.com/
 * @copyright Copyright (c) permanent, ConnectPay Inc.
 * @license   Apache License
 *
 * @see       /LICENSE
 *
 *  International Registered Trademark & Property of ConnectPay Inc.
 */

namespace Invertus\ConnectPay\Infrastructure\Bootstrap;

use Invertus\ConnectPay\Config\TabConfig;
use Invertus\ConnectPay\Infrastructure\Adapter\Language;
use Invertus\ConnectPay\Infrastructure\Adapter\ModuleFactory;
use Invertus\ConnectPay\Infrastructure\Adapter\Tab;

class ModuleTabInstaller implements InstallerInterface
{
    private $moduleFactory;
    private $tab;
    private $language;
    private $moduleTabs;

    public function __construct(
        ModuleFactory $moduleFactory,
        Tab $tab,
        Language $language,
        TabConfig $moduleTabs
    ) {
        $this->moduleFactory = $moduleFactory;
        $this->tab = $tab;
        $this->language = $language;
        $this->moduleTabs = $moduleTabs;
    }

    public function init(): void
    {
        if (!$this->installTabs()) {
            throw new ApplicationBootstrapException('Failed to install module tabs', ApplicationBootstrapException::FAILED_TO_INSTALL_MODULE_TABS);
        }
    }

    private function installTab(string $className, $parent, string $name): bool
    {
        $module = $this->moduleFactory->getModule();

        $idParent = is_int($parent) ? $parent : $this->tab->getIdFromClassName($parent);
        $moduleTab = $this->tab->initTab();
        $moduleTab->class_name = $className;
        $moduleTab->id_parent = $idParent;
        $moduleTab->module = $module->name;

        $languages = $this->language->getAllLanguages();
        foreach ($languages as $language) {
            $moduleTab->name[$language['id_lang']] = $name;
        }

        if (!$moduleTab->save()) {
            return false;
        }

        return true;
    }

    private function installTabs(): bool
    {
        $tabs = $this->moduleTabs->getTabs();

        foreach ($tabs as $tab) {
            if ($this->tab->getIdFromClassName($tab['class_name'])) {
                continue;
            }

            if (!$this->installTab($tab['class_name'], $tab['parent_class_name'], $tab['name'])) {
                return false;
            }
        }

        return true;
    }
}
