<?php
/**
 * NOTICE OF LICENSE
 *
 * @author    Connectpay  <https://connectpay.com/
 * @copyright Copyright (c) permanent, ConnectPay Inc.
 * @license   Apache License
 *
 * @see       /LICENSE
 *
 *  International Registered Trademark & Property of ConnectPay Inc.
 */

declare(strict_types=1);

namespace Invertus\ConnectPay\Infrastructure\Bootstrap;

use Invertus\ConnectPay\Config\TabConfig;
use Invertus\ConnectPay\Infrastructure\Adapter\Tab;

class ModuleTabUninstaller implements InstallerInterface
{
    private $tab;
    private $moduleTabs;

    public function __construct(
        Tab $tab,
        TabConfig $moduleTabs
    ) {
        $this->tab = $tab;
        $this->moduleTabs = $moduleTabs;
    }

    public function init(): void
    {
        if (!$this->uninstallTabs()) {
            throw new ApplicationBootstrapException('Failed to uninstall module tabs', ApplicationBootstrapException::FAILED_TO_UNINSTALL_MODULE_TABS);
        }
    }

    private function uninstallTabs(): bool
    {
        $tabs = $this->moduleTabs->getTabs();

        foreach ($tabs as $tab) {
            $idTab = $this->tab->getIdFromClassName($tab['class_name']);

            if (!$idTab) {
                continue;
            }

            $tabObj = $this->tab->initTab($idTab);

            if (!$tabObj->delete()) {
                return false;
            }
        }

        return true;
    }
}
