<?php
/**
 * NOTICE OF LICENSE
 *
 * @author    Connectpay  <https://connectpay.com/
 * @copyright Copyright (c) permanent, ConnectPay Inc.
 * @license   Apache License
 *
 * @see       /LICENSE
 *
 *  International Registered Trademark & Property of ConnectPay Inc.
 */

declare(strict_types = 1);

namespace Invertus\ConnectPay\Infrastructure\Notification;

use Invertus\ConnectPay\Infrastructure\Adapter\PrestaShopCookie;

class ErrorNotification implements NotificationInterface
{
    private const ID = 'CONNECTPAY_ERROR_NOTIFICATION';

    private $cookie;

    public function __construct(PrestaShopCookie $cookie)
    {
        $this->cookie = $cookie;
    }

    public function setMessage(string $message)
    {
        $this->cookie->set(self::ID, $message);
    }

    public function getMessage(): ?string
    {
        $value = $this->cookie->get(self::ID);

        if (!$value) {
            return null;
        }

        $this->cookie->clear(self::ID);

        return $value;
    }

    public function setMessages(array $messages)
    {
        $this->cookie->set(self::ID, json_encode($messages));
    }

    public function getMessages(): array
    {
        $value = $this->cookie->get(self::ID);

        if (!$value) {
            return [];
        }

        $this->cookie->clear(self::ID);
        $value = json_decode($value, false);

        if (!is_array($value)) {
            return [];
        }

        array_map('stripslashes', $value);

        return $value;
    }
}
