<?php
/**
 * NOTICE OF LICENSE
 *
 * @author    Connectpay  <https://connectpay.com/
 * @copyright Copyright (c) permanent, ConnectPay Inc.
 * @license   Apache License
 *
 * @see       /LICENSE
 *
 *  International Registered Trademark & Property of ConnectPay Inc.
 */

declare(strict_types = 1);

namespace Invertus\ConnectPay\Install;

use Invertus\ConnectPay\Infrastructure\Bootstrap\ApplicationBootstrapException;
use Invertus\ConnectPay\Infrastructure\Bootstrap\DatabaseTableInstaller;
use Invertus\ConnectPay\Infrastructure\Bootstrap\InstallerInterface;
use Invertus\ConnectPay\Infrastructure\Bootstrap\ModuleTabInstaller;
use Invertus\ConnectPay\Infrastructure\Bootstrap\OrderStateInstaller;
use Invertus\ConnectPay\Infrastructure\Utility\VersionUtility;
use Psr\Log\LoggerInterface;

/**
 * Class Installer - responsible for module installation process
 */
class Installer implements InstallerInterface
{
    private $orderStateInstaller;
    private $databaseTableInstaller;
    private $logger;
    private $moduleTabInstaller;

    public function __construct(
        OrderStateInstaller $orderStateInstaller,
        DatabaseTableInstaller $databaseTableInstaller,
        LoggerInterface $logger,
        ModuleTabInstaller $moduleTabInstaller
    ) {
        $this->orderStateInstaller = $orderStateInstaller;
        $this->databaseTableInstaller = $databaseTableInstaller;
        $this->logger = $logger;
        $this->moduleTabInstaller = $moduleTabInstaller;
    }

    /**
     * @throws ApplicationBootstrapException
     */
    public function init(): void
    {
        try {
            $this->databaseTableInstaller->init();
            $this->orderStateInstaller->init();

            if (VersionUtility::isPsVersionLowerThan1700()) {
                $this->moduleTabInstaller->init();
            }
        } catch (ApplicationBootstrapException $e) {
            $this->logger->error($e->getMessage(), ['code' => $e->getCode()]);

            throw $e;
        }
    }
}
