<?php
/**
 * NOTICE OF LICENSE
 *
 * @author    Connectpay  <https://connectpay.com/
 * @copyright Copyright (c) permanent, ConnectPay Inc.
 * @license   Apache License
 *
 * @see       /LICENSE
 *
 *  International Registered Trademark & Property of ConnectPay Inc.
 */

namespace Invertus\ConnectPay;

use League\Container\Container;
use League\Container\ReflectionContainer;
use Psr\Log\LoggerInterface;

/**
 * Main entry point for you container.
 * @see https://container.thephpleague.com/3.x/ for more information of how to use container.
 */
final class LeagueContainerProvider implements ContainerProviderInterface
{
    private $extendedServices = [];

    /**
     * @inheritdoc
     */
    public function getService(string $serviceName)
    {
        $container = new Container();

        // auto wiring @see https://container.thephpleague.com/3.x/auto-wiring/
        $reflectionContainer = (new ReflectionContainer())->cacheResolutions();

        // Fun fact - you can delegate all the containers which implements \Psr\Container\ContainerInterface meaning
        // that as well you can use prestashop container together with this one.
        $container->delegate($reflectionContainer);

        // most of the services will not work automatically, however interface, factories etc...
        // must be defined here.
        $container->add(LoggerInterface::class, NullLogger::class);


        foreach ($this->extendedServices as $extendedService) {
            $container->extend($extendedService['id'])->setConcrete($extendedService['concrete']);
        }

        return $container->get($serviceName);
    }

    /**
     * @inheritdoc
     */
    public function extend(string $id, $concrete = null): ContainerProviderInterface
    {
        $this->extendedServices[] = [
            'id' => $id,
            'concrete' => $concrete,
        ];

        return $this;
    }
}
