<?php
/**
 * NOTICE OF LICENSE
 *
 * @author    Connectpay  <https://connectpay.com/
 * @copyright Copyright (c) permanent, ConnectPay Inc.
 * @license   Apache License
 *
 * @see       /LICENSE
 *
 *  International Registered Trademark & Property of ConnectPay Inc.
 */

declare(strict_types=1);

namespace Invertus\ConnectPay\OAuth\AccessToken;

use Invertus\ConnectPay\Adapter\Configuration;
use Invertus\ConnectPay\Config\ConnectPayConfig;
use Invertus\ConnectPay\Infrastructure\Context\GlobalShopContextInterface;
use Invertus\ConnectPay\OAuth\DTO\ApplicationContext;

class ApplicationContextProvider
{
    private $configuration;
    private $prestaShopContext;

    /**
     * @var ApplicationContext
     */
    private $applicationContext;

    public function __construct(
        Configuration $configuration,
        GlobalShopContextInterface $prestaShopContext
    ) {
        $this->configuration = $configuration;
        $this->prestaShopContext = $prestaShopContext;
    }

    public function get(): ApplicationContext
    {
        if ($this->applicationContext) {
            return  $this->applicationContext;
        }

        $this->applicationContext = new ApplicationContext(
            $this->configuration->get(ConnectPayConfig::CLIENT_KEY, $this->prestaShopContext->getShopId()),
            $this->configuration->get(ConnectPayConfig::CLIENT_SECRET, $this->prestaShopContext->getShopId()),
            $this->configuration->get(ConnectPayConfig::PRIVATE_KEY_FROM_PEM, $this->prestaShopContext->getShopId()),
            $this->configuration->get(ConnectPayConfig::AUTH_CODE, $this->prestaShopContext->getShopId()),
            $this->configuration->get(ConnectPayConfig::BRAND_ID, $this->prestaShopContext->getShopId()),
            $this->configuration->get(ConnectPayConfig::CARD, $this->prestaShopContext->getShopId()),
            $this->configuration->get(ConnectPayConfig::PID, $this->prestaShopContext->getShopId())
        );

        return $this->applicationContext;
    }
}
