<?php
/**
 * NOTICE OF LICENSE
 *
 * @author    Connectpay  <https://connectpay.com/
 * @copyright Copyright (c) permanent, ConnectPay Inc.
 * @license   Apache License
 *
 * @see       /LICENSE
 *
 *  International Registered Trademark & Property of ConnectPay Inc.
 */

declare(strict_types=1);

namespace Invertus\ConnectPay\OAuth\Configuration;

use Invertus\ConnectPay\Adapter\Configuration;
use Invertus\ConnectPay\Adapter\Tools;
use Invertus\ConnectPay\Config\ConnectPayConfig;
use Invertus\ConnectPay\Exception\ConnectPayException;
use Invertus\ConnectPay\Infrastructure\Adapter\ModuleFactory;
use Invertus\ConnectPay\Infrastructure\Context\GlobalShopContextInterface;

class UpdatePrivateKeyHandler
{
    private $module;
    private $configuration;
    private $prestaShopContext;
    private $tools;

    public function __construct(
        Configuration $configuration,
        GlobalShopContextInterface $globalShopContext,
        Tools $tools,
        ModuleFactory $module
    ) {
        $this->configuration = $configuration;
        $this->prestaShopContext = $globalShopContext;
        $this->tools = $tools;
        $this->module = $module->getModule();
    }

    public function handle(
        string $privateKey
    ):void {
        $privateKeyPassword = $this->createPrivateKeyPassword();
        $this->configuration->set(
            ConnectPayConfig::PRIVATE_KEY_PASSWORD,
            $privateKeyPassword,
            $this->prestaShopContext->getShopId()
        );

        $this->savePrivateKeyFile($privateKey);
    }

    private function createPrivateKeyPassword(): string
    {
        return $this->tools->encrypt((string) time());
    }

    private function savePrivateKeyFile($privateKeyUnencrypted): void
    {
        $success = file_put_contents(
            $this->module->getLocalPath()."files/private.pem",
            $privateKeyUnencrypted
        );

        if (!$success) {
            throw new ConnectPayException(
                'Error occurred during Private Key saving.'
            );
        }
    }
}
