<?php
/**
 * NOTICE OF LICENSE
 *
 * @author    Connectpay  <https://connectpay.com/
 * @copyright Copyright (c) permanent, ConnectPay Inc.
 * @license   Apache License
 *
 * @see       /LICENSE
 *
 *  International Registered Trademark & Property of ConnectPay Inc.
 */

declare(strict_types=1);

namespace Invertus\ConnectPay\Payment\API;

use GuzzleHttp\Exception\ClientException;
use Invertus\ConnectPay\Config\ConnectPayConfig;
use Invertus\ConnectPay\Infrastructure\API\ApiRequest;
use Invertus\ConnectPay\Payment\DTO\InitializeApiRequest;
use ConnectPayLog;
use stdClass;

class InitializePaymentApiRequest
{
    private $apiRequest;
    private $initializeApiRequestDTO;
    private $initiatePaymentUrl;

    public function __construct(
        ApiRequest $apiRequest,
        InitializeApiRequest $initializeApiRequestDTO
    ) {
        $this->apiRequest = $apiRequest;
        $this->initializeApiRequestDTO = $initializeApiRequestDTO;
        $this->initiatePaymentUrl = ConnectPayConfig::getApplicationUrl() . '/merchant/payments';
    }

    public function initializePayment(string $providerCode): ?stdClass
    {
        $body = $this->initializeApiRequestDTO->getRequestData($this->initiatePaymentUrl, $providerCode);

        try {
            $response = $this->apiRequest->post(
                $this->initiatePaymentUrl,
                $body
            );
        } catch (ClientException $exception) {
            $logs = new ConnectPayLog();
            $logs->message = $exception->getResponse()->getBody()->getContents();
            $logs->payload = $exception->getCode();
            $logs->add();

            return null;
        }

	    return json_decode($response->getBody()->getContents());
    }
}
