<?php
/**
 * NOTICE OF LICENSE
 *
 * @author    Connectpay  <https://connectpay.com/
 * @copyright Copyright (c) permanent, ConnectPay Inc.
 * @license   Apache License
 *
 * @see       /LICENSE
 *
 *  International Registered Trademark & Property of ConnectPay Inc.
 */

declare(strict_types=1);

namespace Invertus\ConnectPay\Payment\DTO;

use Invertus\ConnectPay\Infrastructure\Utility\VersionUtility;

class PaymentOptionData
{
    private $callToActionText;

    private $additionalInformation;

    private $logo;

    private $action;

    private $inputs;

    private $moduleName;

    public function getCallToActionText(): string
    {
        return $this->callToActionText;
    }

    public function setCallToActionText(string $callToActionText): PaymentOptionData
    {
        $this->callToActionText = $callToActionText;

        return $this;
    }

    public function getAdditionalInformation(): string
    {
        return $this->additionalInformation;
    }

    public function setAdditionalInformation(string $additionalInformation): PaymentOptionData
    {
        $this->additionalInformation = $additionalInformation;

        return $this;
    }

    public function getLogo(): string
    {
        return $this->logo;
    }

    public function setLogo(string $logo): PaymentOptionData
    {
        $this->logo = $logo;

        return $this;
    }

    public function getAction(): string
    {
        return $this->action;
    }

    public function setAction(string $action): PaymentOptionData
    {
        $this->action = $action;

        return $this;
    }

    public function getInputs()
    {
        return $this->inputs;
    }

    public function setInputs(array $inputs): PaymentOptionData
    {
        $this->inputs = $inputs;

        return $this;
    }

    public function getModuleName()
    {
        return $this->moduleName;
    }

    public function setModuleName(string $moduleName): PaymentOptionData
    {
        $this->moduleName = $moduleName;

        return $this;
    }

    private function toArray(): array
    {
        return [
            'module_name' => $this->getModuleName(),
            'action' => $this->getAction(),
            'inputs' => $this->getInputs(),
            'logo' => $this->logo,
            'call_to_action_text' => $this->getCallToActionText(),
        ];
    }

    public function build()
    {
        if (!VersionUtility::isPsVersionLowerThan1700()) {
            return (new \PrestaShop\PrestaShop\Core\Payment\PaymentOption())
                ->setCallToActionText($this->getCallToActionText())
                ->setAdditionalInformation($this->getAdditionalInformation())
                ->setLogo(_MODULE_DIR_.'connectpay/views/img/logov2.png')
                ->setAction($this->getAction())
                ->setInputs($this->getInputs())
                ->setModuleName($this->getModuleName());
        }

        return $this->toArray();
    }
}
