<?php
/**
 * NOTICE OF LICENSE
 *
 * @author    Connectpay  <https://connectpay.com/
 * @copyright Copyright (c) permanent, ConnectPay Inc.
 * @license   Apache License
 *
 * @see       /LICENSE
 *
 *  International Registered Trademark & Property of ConnectPay Inc.
 */

declare(strict_types=1);

namespace Invertus\ConnectPay\Payment\Service;

use ConnectPay;
use Context;
use Order;

class CallBackLinkService
{
    private $module;
    private $context;

    public function __construct(
        ConnectPay $module
    ) {
        $this->module = $module;
        $this->context = Context::getContext();
    }

    public function getPaymentCallBackLink(): string
    {
        $cartId = $this->context->cart->id;

	    return $this->context->link->getModuleLink(
	        $this->module->name,
	        'success',
	        [
	            'cartId' => $cartId,
	            'secureKey' => $this->context->cart->secure_key,
	            'orderId' => Order::getOrderByCartId($cartId),
	            'moduleId' => $this->module->id,
	        ],
	        true
	    );
    }

    public function getPaymentFailLink(): string
    {
        $cartId = $this->context->cart->id;

	    return $this->context->link->getModuleLink(
	        $this->module->name,
	        'fail',
	        [
	            'cartId' => $cartId,
	            'secureKey' => $this->context->cart->secure_key,
	            'orderId' => Order::getOrderByCartId($cartId),
	            'moduleId' => $this->module->id,
	        ],
	        true
	    );
    }
}
