<?php
/**
 * NOTICE OF LICENSE
 *
 * @author    Connectpay  <https://connectpay.com/
 * @copyright Copyright (c) permanent, ConnectPay Inc.
 * @license   Apache License
 *
 * @see       /LICENSE
 *
 *  International Registered Trademark & Property of ConnectPay Inc.
 */

declare(strict_types=1);

namespace Invertus\ConnectPay\Payment\Service;

use Invertus\ConnectPay\Adapter\Configuration;
use Invertus\ConnectPay\Infrastructure\Context\GlobalShopContextInterface;
use Invertus\ConnectPay\OAuth\Provider\PrivateKeyFilePathProvider;
use Tools;

class SignatureService
{
    private $privateKeyFilePathProvider;
    private $configuration;
    private $globalShopContext;

    public function __construct(
        PrivateKeyFilePathProvider $privateKeyFilePathProvider,
        Configuration $configuration,
        GlobalShopContextInterface $globalShopContext
    ) {
        $this->privateKeyFilePathProvider = $privateKeyFilePathProvider;
        $this->configuration = $configuration;
        $this->globalShopContext = $globalShopContext;
    }

    public function generateSignature(string $requestMethod, string $requestUrl, string $requestBody = ''): string
    {
        // Get PrivateKeyInfo.
        $privateKeyInfo = Tools::file_get_contents($this->privateKeyFilePathProvider->getPrivateKeyFilePath());

        // Get PrivateKeyInfo from DB.


        // Preparing URL for signature.
        $requestUrl = strtolower(str_replace("https://", "", $requestUrl));

        // Preparing data for signature.
        $data = "{$requestMethod}|{$requestUrl}|{$requestBody}";

        // compute signature
        openssl_sign($data, $signature, $privateKeyInfo, OPENSSL_ALGO_SHA256);
        $signature = base64_encode($signature);

        return $signature;
    }
}

