<?php
/**
 * NOTICE OF LICENSE
 *
 * @author    Connectpay  <https://connectpay.com/
 * @copyright Copyright (c) permanent, ConnectPay Inc.
 * @license   Apache License
 *
 * @see       /LICENSE
 *
 *  International Registered Trademark & Property of ConnectPay Inc.
 */

declare(strict_types=1);

namespace Invertus\ConnectPay\Payment\Service;

use GuzzleHttp\Exception\ClientException;
use GuzzleHttp\Exception\RequestException;
use Invertus\ConnectPay\Config\ConnectPayConfig;
use ConnectPayLog;
use ConnectPayOrder;
use Invertus\ConnectPay\Payment\API\PaymentStatusApiRequest;
use Invertus\ConnectPay\Payment\Repository\ConnectPayOrderRepository;
use Order;
use Configuration;

class UpdateOrdersStateService
{
    private $orderRepository;
    private $paymentStatusApiRequest;

    public function __construct(
        ConnectPayOrderRepository $orderRepository,
        PaymentStatusApiRequest $paymentStatusApiRequest
    ) {
        $this->orderRepository = $orderRepository;
        $this->paymentStatusApiRequest = $paymentStatusApiRequest;
    }

    public function updateOrdersState(): void
    {
        $notFinalizedOrders = $this->orderRepository->getNotFinalizedOrders();
        $paymentFailedStatus = Configuration::get(ConnectPayConfig::ORDER_STATUSES['Failed']);
        if (!empty($notFinalizedOrders)) {
            foreach ($notFinalizedOrders as $notFinalizedOrder) {
                try {

                    $order = new Order((int) $notFinalizedOrder['id_order']);

                    if ((int)$order->current_state === (int)$paymentFailedStatus) {
                        continue;
                    }

                    $connectPayOrderInformationResponse = $this->paymentStatusApiRequest->getPaymentDetails(
                        (int) $notFinalizedOrder['id_order']
                    );

                    if ($connectPayOrderInformationResponse === null) {
                        $order->setCurrentState((int)$paymentFailedStatus);
                    } else {
                        $orderState = $connectPayOrderInformationResponse->status->code;

                        $newState = (isset(ConnectPayConfig::ORDER_STATUSES[$orderState])) ?
                            Configuration::get(ConnectPayConfig::ORDER_STATUSES[$orderState]) :
                            Configuration::get(ConnectPayConfig::ORDER_STATUS_AWAITING_PAYMENT);

                        if ((int) $order->current_state !== (int) $newState) {
                            $order->setCurrentState($newState);
                            $connectPayOrder = new ConnectPayOrder($notFinalizedOrder['id_connectpay_order']);
                            $connectPayOrder->order_finalized = (bool) $connectPayOrderInformationResponse->status->isTerminal;
                            $connectPayOrder->save();
                        }
                    }

                } catch (ClientException | RequestException $exception) {
                    $logs = new ConnectPayLog();
                    $logs->message = $exception->getResponse()->getBody()->getContents();
                    $logs->payload = $exception->getCode();
                    $logs->add();
                }
            }
        }
    }
}
